pub enum ClientError {
Http(Error),
Json(Error),
Server {
status: u16,
message: String,
code: Option<ServerErrorCode>,
},
Authorization {
status: u16,
message: String,
code: Option<ServerErrorCode>,
},
Config(String),
NamespaceNotFound(String),
VectorNotFound(String),
InvalidUrl(String),
Connection(String),
Timeout,
}Expand description
Errors that can occur when using the Dakera client
Variants
Http(Error)
HTTP request failed
Json(Error)
JSON serialization/deserialization failed
Server
Server returned an error response
Fields
Authorization
403 Forbidden — insufficient scope or namespace access denied
Config(String)
Invalid configuration
NamespaceNotFound(String)
Namespace not found
VectorNotFound(String)
Vector not found
InvalidUrl(String)
Invalid URL
Connection(String)
Connection failed
Timeout
Timeout
Implementations
Sourceimpl ClientError
impl ClientError
Sourcepub fn is_retryable(&self) -> bool
pub fn is_retryable(&self) -> bool
Check if the error is retryable
Sourcepub fn is_not_found(&self) -> bool
pub fn is_not_found(&self) -> bool
Check if the error is a not found error
Sourcepub fn is_auth_error(&self) -> bool
pub fn is_auth_error(&self) -> bool
Check if the error is an authorization/authentication error