pub struct QueryTextRequest {
pub text: String,
pub top_k: u32,
pub filter: Option<Value>,
pub include_text: bool,
pub include_vectors: bool,
pub model: Option<EmbeddingModel>,
}Expand description
Request to query using natural language text with automatic embedding.
Fields
text: StringQuery text.
top_k: u32Number of results to return.
filter: Option<Value>Optional metadata filter.
include_text: boolWhether to include the original text in results.
include_vectors: boolWhether to include vectors in results.
model: Option<EmbeddingModel>Embedding model to use (default: minilm).
Implementations
Sourceimpl QueryTextRequest
impl QueryTextRequest
Sourcepub fn with_filter(self, filter: Value) -> Self
pub fn with_filter(self, filter: Value) -> Self
Add a metadata filter.
Sourcepub fn include_text(self, include: bool) -> Self
pub fn include_text(self, include: bool) -> Self
Set whether to include the original text in results.
Sourcepub fn include_vectors(self, include: bool) -> Self
pub fn include_vectors(self, include: bool) -> Self
Set whether to include vectors in results.
Sourcepub fn with_model(self, model: EmbeddingModel) -> Self
pub fn with_model(self, model: EmbeddingModel) -> Self
Set the embedding model.